@@ -1,7 +1,7 @@
 ﻿// samplv1.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2020, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2021, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -45,10 +45,10 @@
 
 
 #ifdef CONFIG_DEBUG_0
-#include <stdio.h>
+#include <cstdio>
 #endif
 
-#include <string.h>
+#include <cstring>
 
 
 //-------------------------------------------------------------------------
@@ -1773,8 +1773,8 @@ void samplv1_impl::process_midi ( uint8_t *data, uint32_t size )
 					m_dca1.env.start(&pv->dca1_env);
 				else
 					m_dca1.env.idle(&pv->dca1_env);
-				if (gen1_sample.isLoop())
-					pv->gen1.setLoop(*m_dca1.enabled > 0.0f);
+				// something about the loop
+				pv->gen1.setLoop(gen1_sample.isLoop());
 				// lfos
 				const float lfo1_pshift
 					= (m_lfo1.psync ? m_lfo1.psync->lfo1.pshift() : 0.0f);
