@@ -1,7 +1,7 @@
 // samplv1_jack.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2020, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2021, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -28,10 +28,9 @@
 
 #include <jack/midiport.h>
 
-#include <stdio.h>
-#include <string.h>
-
-#include <math.h>
+#include <cstdio>
+#include <cstring>
+#include <cmath>
 
 #include <QCoreApplication>
 #include <QDir>
@@ -289,9 +288,11 @@ int samplv1_jack::process ( jack_nframes_t nframes )
 
 
 #ifdef CONFIG_JACK_SESSION
+#if defined(Q_CC_GNU) || defined(Q_CC_MINGW)
 #pragma GCC diagnostic push
 #pragma GCC diagnostic ignored "-Wdeprecated-declarations"
 #endif
+#endif
 
 void samplv1_jack::open ( const char *client_name )
 {
@@ -380,8 +381,10 @@ void samplv1_jack::open ( const char *client_name )
 }
 
 #ifdef CONFIG_JACK_SESSION
+#if defined(Q_CC_GNU) || defined(Q_CC_MINGW)
 #pragma GCC diagnostic pop
 #endif
+#endif
 
 
 void samplv1_jack::activate (void)
@@ -573,8 +576,10 @@ void samplv1_jack::alsa_capture ( snd_seq_event_t *ev )
 
 #ifdef CONFIG_JACK_SESSION
 
+#if defined(Q_CC_GNU) || defined(Q_CC_MINGW)
 #pragma GCC diagnostic push
 #pragma GCC diagnostic ignored "-Wdeprecated-declarations"
+#endif
 
 // JACK session event handler.
 void samplv1_jack::sessionEvent ( void *pvSessionArg )
@@ -619,7 +624,9 @@ void samplv1_jack::sessionEvent ( void *pvSessionArg )
 	#endif
 }
 
+#if defined(Q_CC_GNU) || defined(Q_CC_MINGW)
 #pragma GCC diagnostic pop
+#endif
 
 #endif	// CONFIG_JACK_SESSION
 
@@ -1097,8 +1104,14 @@ void samplv1_jack_application::handle_sigterm (void)
 	char c;
 
 	if (::read(g_fdSigterm[1], &c, sizeof(c)) > 0) {
-		if (m_pApp)
-			m_pApp->quit();
+		if (m_pApp && m_pWidget) {
+		#ifdef CONFIG_NSM
+			if (m_pNsmClient && m_pNsmClient->is_active())
+				m_pWidget->updateDirtyPreset(false);
+		#endif
+			if (m_pWidget->queryClose())
+				m_pApp->quit();
+		}
 	}
 }
 
