@@ -1,7 +1,7 @@
 // samplv1_lv2.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2020, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2021, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -61,8 +61,8 @@
 #define LV2_ATOM__portTuple LV2_ATOM_PREFIX "portTuple"
 #endif
 
-#include <stdlib.h>
-#include <math.h>
+#include <cstdlib>
+#include <cmath>
 
 #include <QApplication>
 #include <QDomDocument>
@@ -211,14 +211,14 @@ samplv1_lv2::samplv1_lv2 (
 		if (host_option->type == m_urids.atom_Int) {
 			uint32_t block_length = 0;
 			if (host_option->key == m_urids.bufsz_minBlockLength)
-				block_length = *(int *) host_option->value;
+				block_length = *(int32_t *) host_option->value;
 			else
 			if (host_option->key == m_urids.bufsz_maxBlockLength)
-				block_length = *(int *) host_option->value;
+				block_length = *(int32_t *) host_option->value;
 		#ifdef LV2_BUF_SIZE__nominalBlockLength
 			else
 			if (host_option->key == m_urids.bufsz_nominalBlockLength)
-				block_length = *(int *) host_option->value;
+				block_length = *(int32_t *) host_option->value;
 		#endif
 			// choose the lengthier...
 			if (buffer_size < block_length)
@@ -361,7 +361,7 @@ void samplv1_lv2::run ( uint32_t nframes )
 							samplv1_sample *pSample = samplv1::sample();
 							if (pSample) {
 								const uint32_t offset_start
-									= *(uint32_t *) LV2_ATOM_BODY_CONST(value);
+									= *(int32_t *) LV2_ATOM_BODY_CONST(value);
 								const uint32_t offset_end
 									= pSample->offsetEnd();
 								setOffsetRange(offset_start, offset_end, true);
@@ -378,7 +378,7 @@ void samplv1_lv2::run ( uint32_t nframes )
 								const uint32_t offset_start
 									= pSample->offsetStart();
 								const uint32_t offset_end
-									= *(uint32_t *) LV2_ATOM_BODY_CONST(value);
+									= *(int32_t *) LV2_ATOM_BODY_CONST(value);
 								setOffsetRange(offset_start, offset_end, true);
 							}
 						}
@@ -391,7 +391,7 @@ void samplv1_lv2::run ( uint32_t nframes )
 							samplv1_sample *pSample = samplv1::sample();
 							if (pSample) {
 								const uint32_t loop_start
-									= *(uint32_t *) LV2_ATOM_BODY_CONST(value);
+									= *(int32_t *) LV2_ATOM_BODY_CONST(value);
 								const uint32_t loop_end
 									= pSample->loopEnd();
 								setLoopRange(loop_start, loop_end, true);
@@ -408,7 +408,7 @@ void samplv1_lv2::run ( uint32_t nframes )
 								const uint32_t loop_start
 									= pSample->loopStart();
 								const uint32_t loop_end
-									= *(uint32_t *) LV2_ATOM_BODY_CONST(value);
+									= *(int32_t *) LV2_ATOM_BODY_CONST(value);
 								setLoopRange(loop_start, loop_end, true);
 							}
 						}
@@ -419,7 +419,7 @@ void samplv1_lv2::run ( uint32_t nframes )
 						#endif
 							) && type == m_urids.atom_Int) {
 							const uint32_t loop_fade
-								= *(uint32_t *) LV2_ATOM_BODY_CONST(value);
+								= *(int32_t *) LV2_ATOM_BODY_CONST(value);
 							setLoopFade(loop_fade, true);
 						}
 						else
@@ -433,7 +433,7 @@ void samplv1_lv2::run ( uint32_t nframes )
 						#endif
 							)) {
 							const uint32_t loop_zero
-								= *(uint32_t *) LV2_ATOM_BODY_CONST(value);
+								= *(int32_t *) LV2_ATOM_BODY_CONST(value);
 							setLoopZero(loop_zero > 0, true);
 						}
 						else
@@ -444,7 +444,7 @@ void samplv1_lv2::run ( uint32_t nframes )
 								mesg.atom.type = key;
 								mesg.atom.size = sizeof(mesg.data.key);
 								mesg.data.key
-									= *(uint32_t *) LV2_ATOM_BODY_CONST(value);
+									= *(int32_t *) LV2_ATOM_BODY_CONST(value);
 								// schedule loading new sample
 								m_schedule->schedule_work(
 									m_schedule->handle, sizeof(mesg), &mesg);
@@ -453,8 +453,8 @@ void samplv1_lv2::run ( uint32_t nframes )
 						else
 						if (key == m_urids.p201_tuning_enabled
 							&& type == m_urids.atom_Bool) {
-							const uint32_t enabled
-								= *(uint32_t *) LV2_ATOM_BODY_CONST(value);
+							const int32_t enabled
+								= *(int32_t *) LV2_ATOM_BODY_CONST(value);
 							samplv1::setTuningEnabled(enabled > 0);
 							updateTuning();
 						}
@@ -469,8 +469,8 @@ void samplv1_lv2::run ( uint32_t nframes )
 						else
 						if (key == m_urids.p203_tuning_refNote
 							&& type == m_urids.atom_Int) {
-							const uint32_t refNote
-								= *(uint32_t *) LV2_ATOM_BODY_CONST(value);
+							const int32_t refNote
+								= *(int32_t *) LV2_ATOM_BODY_CONST(value);
 							samplv1::setTuningRefNote(refNote);
 							updateTuning();
 						}
