@@ -1,7 +1,7 @@
 // samplv1widget_config.h
 //
 /****************************************************************************
-   Copyright (C) 2012-2019, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2020, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -46,8 +46,7 @@ class samplv1widget_config : public QDialog
 public:
 
 	// ctor.
-	samplv1widget_config(samplv1_ui *pSamplUi,
-		QWidget *pParent = 0, Qt::WindowFlags wflags = 0);
+	samplv1widget_config(samplv1_ui *pSamplUi, QWidget *pParent = nullptr);
 
 	// dtor.
 	~samplv1widget_config();
