@@ -1,7 +1,7 @@
 // samplv1widget_status.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2019, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2020, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -59,7 +59,7 @@ samplv1widget_status::samplv1widget_status ( QWidget *pParent )
 	pMidiInWidget->setToolTip(tr("%1 status").arg(sMidiIn));
 
 	QHBoxLayout *pMidiInLayout = new QHBoxLayout();
-	pMidiInLayout->setMargin(0);
+	pMidiInLayout->setContentsMargins(0, 0, 0, 0);
 	pMidiInLayout->setSpacing(0);
 
 	m_pMidiInLedLabel = new QLabel();
